const {
    Card,
    CardHeader,
    CardContent,
    FormControl,
    FormLabel,
    TextField,
    Button
} = window['material-ui'];

class LoginForm extends React.Component{
    state = {
        isValidUsername: false,
        isValidPassword: false,
        username: "",
        password: "",
        errorsMessage: ""
    };

    handleChangeUsername = event => {
        this.setState({
            username: event.target.value,
            isValidUsername: /^[_'.@A-Za-z0-9-]*$/.test(event.target.value)
        });
    };

    handleChangePassword = event => {
        this.setState({
            password: event.target.value,
            isValidPassword: (event.target.value.length > 4)
        });
    };

    handleSubmit = loginForm => () => {
        if (loginForm.state.isValidUsername && loginForm.state.isValidPassword){
            $.post(
                "/login",
                loginForm.state,
                this.handleResponseAjaxPost(loginForm)("success")
            ).fail(this.handleResponseAjaxPost(loginForm)("error"));
        }
    };

    handleResponseAjaxPost = loginForm => status => response => {
        if (status === "success"){
            window.location.href = "/index";
            loginForm.setState({
                errorsMessage: ""
            });
        } else if (status === "error"){
            loginForm.setState({
                errorsMessage: response.responseText,
                password: "",
                isValidPassword: false
            })
        }
    };

    render(){
        return (
            <Card onKeyPress={e => (e.key === 'Enter' ? this.handleSubmit(this)() : null)} tabIndex="0">
                <CardHeader title="Вход"/>
                <CardContent>
                    <form>
                        <FormControl component="fieldset" style={{width: '100%'}}>
                            <FormLabel error={true}>
                                <div
                                    className="Container"
                                    dangerouslySetInnerHTML={{__html: this.state.errorsMessage}}>
                                </div>
                            </FormLabel>
                            <TextField
                                label="Логин"
                                value={this.state.username}
                                onChange={this.handleChangeUsername}
                                margin="normal"
                                error={!this.state.isValidUsername}
                                helperText={!this.state.isValidUsername ? "Логин не соответствует требованиям ^[_'.@A-Za-z0-9-]*$" : ""}
                            />
                            <TextField
                                label="Пароль"
                                value={this.state.password}
                                onChange={this.handleChangePassword}
                                margin="normal"
                                error={!this.state.isValidPassword}
                                helperText={!this.state.isValidPassword ? "Пароль должен содержать 5 символов" : ""}
                            />
                            <Button
                                variant="contained"
                                onClick={this.handleSubmit(this)}
                                style={{margin: 'auto'}}
                                disabled={!this.state.isValidUsername || !this.state.isValidPassword}
                            >Войти</Button>
                        </FormControl>
                    </form>
                </CardContent>
            </Card>
        );
    }
}